@@ -33,7 +33,7 @@
 #include "rules/chessrules.h"
 #include "ui_promotiondialog.h"
 
-#include <KGameRenderer>
+#include <KGameGraphicsViewRenderer>
 
 #include <QDialog>
 #include <QDialogButtonBox>
@@ -67,7 +67,7 @@ const QString blackLettersKey = QStringLiteral ( "BlackLetters" );
 const QString whiteNumbersKey = QStringLiteral ( "WhiteNumbers" );
 const QString blackNumbersKey = QStringLiteral ( "BlackNumbers" );
 
-Board::Board(KgThemeProvider* provider, QObject* parent) : QGraphicsScene(parent),
+Board::Board(KGameThemeProvider* provider, QObject* parent) : QGraphicsScene(parent),
 	m_rules(nullptr),
 	m_background(nullptr),
 	m_displayBorders(true),
@@ -83,13 +83,13 @@ Board::Board(KgThemeProvider* provider, QObject* parent) : QGraphicsScene(parent
 	m_displayedPlayer(NoColor),
 	m_drawFrame(true) {
 
-	renderer = new KGameRenderer(m_themeProvider);
+	renderer = new KGameGraphicsViewRenderer(m_themeProvider);
 	if (!Manager::self()->rules())
 		Manager::self()->setRules(new ChessRules);
 	Manager::self()->rules()->setGrid(&m_grid);
 	updateTheme();
 
-	connect (provider, &KgThemeProvider::currentThemeChanged, this, &Board::updateTheme);
+	connect (provider, &KGameThemeProvider::currentThemeChanged, this, &Board::updateTheme);
 }
 
 Board::~Board() {
@@ -151,14 +151,14 @@ void Board::movePiece(const Move& move) {
 		}
 		if ( Settings::showDanger() ) {
 			bool check = false;
-			for ( Piece* piece : qAsConst(m_grid) ) {
+			for ( Piece* piece : std::as_const(m_grid) ) {
 				if ( piece->color() == m_currentPlayer && Manager::self()->rules()->isAttacking ( piece->boardPos() ) ) {
 					check = true;
 					addMarker ( piece->boardPos(), Danger );
 				}
 			}
 			if ( check ) {
-				for ( Piece* piece : qAsConst(m_grid) ) {
+				for ( Piece* piece : std::as_const(m_grid) ) {
 					if ( piece->color() != m_currentPlayer && piece->pieceType() == King )
 						addMarker ( piece->boardPos(), Danger );
 				}
@@ -239,7 +239,7 @@ void Board::mousePressEvent(QGraphicsSceneMouseEvent* e) {
 			}
 			d_piece->setZValue ( dragZValue );
 			if ( Settings::showMarker() ) {
-				for ( const Move& t_move : qAsConst(t_legalMoves) )
+				for ( const Move& t_move : std::as_const(t_legalMoves) )
 					addMarker ( t_move.to(), LegalMove );
 			}
 			draggedPiece = d_piece;
@@ -449,7 +449,7 @@ void Board::updateTheme() {
 		m_borders << tItem;
 
 		m_borders << new Item ( renderer, lrBorderKey, this, Pos() );
-		for ( Item* item : qAsConst(m_borders) )
+		for ( Item* item : std::as_const(m_borders) )
 			item->setZValue ( borderZValue );
 	}
 	if ( m_displayNotations ) {
@@ -466,7 +466,7 @@ void Board::updateTheme() {
 		m_notations << new Item ( renderer, numbersKey, this, Pos() );
 		m_notations << new Item ( renderer, lettersKey, this, Pos() );
 		m_notations << new Item ( renderer, numbersKey, this, Pos() );
-		for ( Item* item : qAsConst(m_notations) )
+		for ( Item* item : std::as_const(m_notations) )
 			item->setZValue ( notationZValue );
 	}
 	addTiles();
@@ -526,11 +526,11 @@ void Board::updateGraphics() {
 	QPointF bottomBorderPoint = m_boardRect.bottomLeft() - QPoint ( vBorderMargin, 0 );
 	QPointF leftBorderPoint = m_boardRect.topLeft() - QPoint ( vBorderMargin, 0 );
 
-	for ( Piece* p : qAsConst(m_grid) )
+	for ( Piece* p : std::as_const(m_grid) )
 		centerAndResize ( p, tSize );
-	for ( Item* t : qAsConst(m_tiles) )
+	for ( Item* t : std::as_const(m_tiles) )
 		centerAndResize ( t, tSize, Settings::animateBoard() );
-	for ( Item* t : qAsConst(markers) )
+	for ( Item* t : std::as_const(markers) )
 		centerAndResize ( t, tSize );
 	if ( m_displayBorders ) {
 		m_borders[0]->moveAndResize ( bottomBorderPoint, m_tileSize, hBorderSize, Settings::animateBoard() );
@@ -547,12 +547,12 @@ void Board::updateGraphics() {
 }
 
 void Board::changeDisplayedPlayer() {
-	for ( Piece* p : qAsConst(m_grid) )
+	for ( Piece* p : std::as_const(m_grid) )
 		centerOnPos ( p );
-	for ( Item* i : qAsConst(markers) )
+	for ( Item* i : std::as_const(markers) )
 		centerOnPos ( i );
 	if ( Settings::animateBoard() ) {
-		for ( Item* i : qAsConst(m_tiles) )
+		for ( Item* i : std::as_const(m_tiles) )
 			centerOnPos ( i );
 	}
 	if ( m_displayNotations ) {
