@@ -33,8 +33,8 @@
 #include "knightsdebug.h"
 
 #include <KLocalizedString>
-#include <KgDifficulty>
-#include <KgSound>
+#include <KGameDifficulty>
+#include <KGameSound>
 
 #ifdef HAVE_SPEECH
 #include <QtTextToSpeech>
@@ -82,10 +82,10 @@ public:
 	QMap<int, Offer> offers;
 	QSet<int> usedOfferIds;
 
-	std::unique_ptr<KgSound> captureWhiteSound;
-	std::unique_ptr<KgSound> captureBlackSound;
-	std::unique_ptr<KgSound> moveWhiteSound;
-	std::unique_ptr<KgSound> moveBlackSound;
+	std::unique_ptr<KGameSound> captureWhiteSound;
+	std::unique_ptr<KGameSound> captureBlackSound;
+	std::unique_ptr<KGameSound> moveWhiteSound;
+	std::unique_ptr<KGameSound> moveBlackSound;
 
 #ifdef HAVE_SPEECH
 	QTextToSpeech* speech;
@@ -116,10 +116,10 @@ GameManagerPrivate::GameManagerPrivate()
 	  loading(false) {
 
 	const QDir dir = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds"), QStandardPaths::LocateDirectory);
-	captureWhiteSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("capture_white.ogg"))) );
-	captureBlackSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("capture_black.ogg"))) );
-	moveWhiteSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("move_white.ogg"))) ) ;
-        moveBlackSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("move_black.ogg"))) );
+	captureWhiteSound = std::unique_ptr<KGameSound>( new KGameSound(dir.filePath(QStringLiteral("capture_white.ogg"))) );
+	captureBlackSound = std::unique_ptr<KGameSound>( new KGameSound(dir.filePath(QStringLiteral("capture_black.ogg"))) );
+	moveWhiteSound = std::unique_ptr<KGameSound>( new KGameSound(dir.filePath(QStringLiteral("move_white.ogg"))) ) ;
+        moveBlackSound = std::unique_ptr<KGameSound>( new KGameSound(dir.filePath(QStringLiteral("move_black.ogg"))) );
 }
 
 GameManagerPrivate::~GameManagerPrivate()
@@ -430,8 +430,8 @@ void Manager::startGame() {
 	Q_ASSERT(!d->gameStarted);
 	setRules(new ChessRules);
 	if ( Protocol::white()->supportedFeatures() & Protocol::AdjustDifficulty
-	        || Protocol::black()->supportedFeatures() & Protocol::AdjustDifficulty)
-		levelChanged(Kg::difficulty()->currentLevel());
+	        || Protocol::white()->supportedFeatures() & Protocol::AdjustDifficulty)
+		levelChanged(KGameDifficulty::global()->currentLevel());
 
 	Protocol::white()->startGame();
 	Protocol::black()->startGame();
@@ -742,7 +742,7 @@ void Manager::processMove(const Move& move) {
 		startTime();
 	pendingMove = m;
 	if ( Protocol::byColor(d->activePlayer)->isComputer() )
-		QTimer::singleShot ( Settings::computerDelay(), this, SLOT(sendPendingMove()) );
+		QTimer::singleShot ( Settings::computerDelay(), this, &Manager::sendPendingMove );
 	else
 		sendPendingMove();
 }
@@ -761,32 +761,32 @@ bool Manager::canLocalMove() const {
 	return false;
 }
 
-void Manager::levelChanged ( const KgDifficultyLevel* level ) {
+void Manager::levelChanged ( const KGameDifficultyLevel* level ) {
 	qCDebug(LOG_KNIGHTS);
 	int depth = 0;
 	int size = 32;
 	switch ( level->standardLevel() ) {
-	case KgDifficultyLevel::VeryEasy:
+	case KGameDifficultyLevel::VeryEasy:
 		depth = 1;
 		break;
 
-	case KgDifficultyLevel::Easy:
+	case KGameDifficultyLevel::Easy:
 		depth = 3;
 		break;
 
-	case KgDifficultyLevel::Medium:
+	case KGameDifficultyLevel::Medium:
 		depth = 8;
 		break;
 
-	case KgDifficultyLevel::Hard:
+	case KGameDifficultyLevel::Hard:
 		depth = 16;
 		break;
 
-	case KgDifficultyLevel::VeryHard:
+	case KGameDifficultyLevel::VeryHard:
 		depth = 32;
 		break;
 
-	case KgDifficultyLevel::Custom: {
+	case KGameDifficultyLevel::Custom: {
 			QPointer<DifficultyDialog> dlg = new DifficultyDialog();
 			if ( dlg->exec() == QDialog::Accepted ) {
 				depth = dlg->searchDepth();
