@@ -101,7 +101,7 @@ void UciProtocol::requestNextMove() {
 
 	if ( !mMoveHistory.isEmpty() ) {
 		str += QLatin1String(" moves");
-		for ( const Move& move : qAsConst(mMoveHistory) ) {
+		for ( const Move& move : std::as_const(mMoveHistory) ) {
 			QString moveString = QLatin1Char(' ') + move.from().string() + move.to().string();
 			if ( move.promotedType() )
 				moveString += Piece::charFromType ( move.promotedType() ).toLower();
@@ -112,6 +112,7 @@ void UciProtocol::requestNextMove() {
 
 	QString goString = QStringLiteral("go");
 
+	//TODO: mDifficulty doesn't seem to be properly set nowhere
 	if ( mDifficulty )
 		goString += QLatin1String(" depth ") + QString::number ( mDifficulty );
 
